==> haskell-lrucache-1.2.0.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lrucache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lrucache
version: 1.2.0.1
id: lrucache-1.2.0.1-1tAvykfwj0X9WmhguP8o7G
key: lrucache-1.2.0.1-1tAvykfwj0X9WmhguP8o7G
license: BSD-3-Clause
copyright: Carl Howells, 2010-2015
maintainer: chowells79@gmail.com
author: Carl Howells
stability: Experimental
homepage: http://github.com/chowells79/lrucache
synopsis: a simple, pure LRU cache
description:
    This package contains a simple, pure LRU cache, implemented in
    terms of "Data.Map".
    .
    It also contains a mutable IO wrapper providing atomic updates to
    an LRU cache.
category: Data
abi: ee9ec5aa1be0b740de9364e7efdaff9d
exposed: True
exposed-modules:
    Data.Cache.LRU Data.Cache.LRU.IO Data.Cache.LRU.IO.Internal
    Data.Cache.LRU.Internal
import-dirs: /usr/lib/ghc-8.6.3/site-local/lrucache-1.2.0.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/lrucache-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/lrucache-1.2.0.1
hs-libraries: HSlrucache-1.2.0.1-1tAvykfwj0X9WmhguP8o7G
depends:
    base-4.12.0.0 containers-0.6.0.1
    contravariant-1.5-4tjvhiNPMk29NhGPKE1GIF
haddock-interfaces: /usr/share/doc/haskell-lrucache/html/lrucache.haddock
haddock-html: /usr/share/doc/haskell-lrucache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lrucache-1.2.0.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lrucache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lrucache
version: 1.2.0.1
id: lrucache-1.2.0.1-86gtrGVEDyfFFMCkj0lKw8
key: lrucache-1.2.0.1-86gtrGVEDyfFFMCkj0lKw8
license: BSD-3-Clause
copyright: Carl Howells, 2010-2015
maintainer: chowells79@gmail.com
author: Carl Howells
stability: Experimental
homepage: http://github.com/chowells79/lrucache
synopsis: a simple, pure LRU cache
description:
    This package contains a simple, pure LRU cache, implemented in
    terms of "Data.Map".
    .
    It also contains a mutable IO wrapper providing atomic updates to
    an LRU cache.
category: Data
abi: 1afd3e6fac5a2d7b374b37d385aba13b
exposed: True
exposed-modules:
    Data.Cache.LRU Data.Cache.LRU.IO Data.Cache.LRU.IO.Internal
    Data.Cache.LRU.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/lrucache-1.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/lrucache-1.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/lrucache-1.2.0.1
hs-libraries: HSlrucache-1.2.0.1-86gtrGVEDyfFFMCkj0lKw8
depends:
    base-4.12.0.0 containers-0.6.0.1
    contravariant-1.5-6YjeCNapF4KLECQA4h7stV
haddock-interfaces: /usr/share/doc/haskell-lrucache/html/lrucache.haddock
haddock-html: /usr/share/doc/haskell-lrucache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
